GoogleCloudRecaptchaenterpriseV1AndroidKeySettings

Struct GoogleCloudRecaptchaenterpriseV1AndroidKeySettings 

pub struct GoogleCloudRecaptchaenterpriseV1AndroidKeySettings {
    pub allow_all_package_names: Option<bool>,
    pub allowed_package_names: Option<Vec<String>>,
    pub support_non_google_app_store_distribution: Option<bool>,
}
Settings specific to keys that can be used by Android apps.

This type is not used in any activity, and only used as part of another schema.

Fields

allow_all_package_names: Option<bool>

Optional. If set to true, allowed_package_names are not enforced.

allowed_package_names: Option<Vec<String>>

Optional. Android package names of apps allowed to use the key. Example: ‘com.companyname.appname’ Each key supports a maximum of 250 package names. To use a key on more apps, set allow_all_package_names to true. When this is set, you are responsible for validating the package name by checking the token_properties.android_package_name field in each assessment response against your list of allowed package names.

support_non_google_app_store_distribution: Option<bool>

Optional. Set to true for keys that are used in an Android application that is available for download in app stores in addition to the Google Play Store.